import 'package:flutter/material.dart';
import 'package:vengamo_chat_ui/components/text_widget.dart';
import '../BubbleDesign/whatsapp_arrow.dart';
import 'bubble_text.dart';
import '../dismissable_bubble.dart';
import '../seenStatus.dart';
import 'image_widget.dart';

class ChatBubbleWithoutAvatar extends StatelessWidget {
  
  const  ChatBubbleWithoutAvatar({
    required this.isMe,
    required this.message,
    required this.constraints,
    required this.senderBgColor,
    required this.receiverBgColor,
    required this.isNextMessageFromSameSender,
    required this.pointer,
    required this.ack,
    required this.time,
    required this.timeLabelColor,
    required this.textColor, 
    required this.imgUrl, 
    required this.caption
  });

  final bool isMe;
  final String message;
  final BoxConstraints constraints;
  final Color senderBgColor;
  final Color receiverBgColor;
  final bool isNextMessageFromSameSender;
  final bool pointer;
  final Widget ack;
  final String time;
  final Color timeLabelColor;
  final Color textColor;
   /// Represents the URL of an image.
  final String imgUrl;
  /// Represents the caption or textual description associated with an image.
  final String caption;

  String _extractdata(String message, String imageUrl){
    if (message.isNotEmpty && imageUrl.isEmpty) {
        return 'text';
      } else {
        return 'image';
     }
   }

@override
  Widget build(BuildContext context) {
    /// final size = MediaQuery.of(context).size;
    return DismssibleBubble(
      isMe: isMe,
      message: message,
      child: Wrap(
        children: [
          Stack(
            children: [
              Align(
                alignment: isMe ? Alignment.bottomRight : Alignment.bottomLeft,
                child: Stack(
                  clipBehavior: Clip.none,
                  children: [
                    Column(
                      children: [
                      _extractdata(message,imgUrl) == "image" ? 
                        ImageWidget(
                         imgUrl: imgUrl,
                         caption: caption, 
                         constraints: constraints,
                         color: isMe ? senderBgColor: receiverBgColor,
                          isMe: isMe,
                          textColor: textColor,
                          message: message,
                          ack: ack,
                          time: time,
                          timeLabelColor: timeLabelColor,
                         ) : Container(
                        constraints: BoxConstraints(
                          maxWidth: constraints.maxWidth * 0.8,
                        ),
                        margin: EdgeInsets.only(
                              top: isNextMessageFromSameSender ? 2 : 10,
                              bottom: 1,
                            ),
                        decoration: BoxDecoration(
                              color: isMe ? senderBgColor: receiverBgColor,
                              borderRadius: BorderRadius.only(
                                topLeft: const Radius.circular(9),
                                topRight: const Radius.circular(9),
                                bottomLeft: isMe
                                    ? const Radius.circular(9)
                                    : const Radius.circular(9),
                                bottomRight: const Radius.circular(9),
                              ),
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.13),
                                  blurRadius: 1,
                                  offset: const Offset(0,1),
                                ),
                              ],
                            ),
                        child: textWiget(
                          isMe: isMe,
                          textColor: textColor,
                          message: message,
                          ack: ack,
                          time: time,
                          timeLabelColor: timeLabelColor,
                        ),
                       ),
                      ],
                    ),
    
                  if (isMe && !isNextMessageFromSameSender && pointer)
                      Positioned(
                        right: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(isLeft: false, bg: isMe ? senderBgColor: receiverBgColor),
                          size: const Size(12, 12),
                        ),
                      ),
                    if (!isMe  && !isNextMessageFromSameSender && pointer)
                      Positioned(
                        left: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(isLeft: true,  bg: isMe ? senderBgColor: receiverBgColor),
                          size: Size(12, 12),
                        ),
                      ),
                  ]
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
